[Lldb-commits] [lldb] r156797 - /lldb/trunk/source/Plugins/Process/gdb-remote/GDBRemoteCommunicationClient.cpp

Greg Clayton gclayton at apple.com
Mon May 14 19:50:49 PDT 2012


Author: gclayton
Date: Mon May 14 21:50:49 2012
New Revision: 156797

URL: http://llvm.org/viewvc/llvm-project?rev=156797&view=rev
Log:
Fixed a typo: "aync" => "async"


Modified:
    lldb/trunk/source/Plugins/Process/gdb-remote/GDBRemoteCommunicationClient.cpp

Modified: lldb/trunk/source/Plugins/Process/gdb-remote/GDBRemoteCommunicationClient.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Plugins/Process/gdb-remote/GDBRemoteCommunicationClient.cpp?rev=156797&r1=156796&r2=156797&view=diff
==============================================================================
--- lldb/trunk/source/Plugins/Process/gdb-remote/GDBRemoteCommunicationClient.cpp (original)
+++ lldb/trunk/source/Plugins/Process/gdb-remote/GDBRemoteCommunicationClient.cpp Mon May 14 21:50:49 2012
@@ -435,10 +435,10 @@
 
                         const uint8_t signo = response.GetHexU8 (UINT8_MAX);
 
-                        bool continue_after_aync = false;
+                        bool continue_after_async = false;
                         if (m_async_signal != -1 || m_async_packet_predicate.GetValue())
                         {
-                            continue_after_aync = true;
+                            continue_after_async = true;
                             // We sent an interrupt packet to stop the inferior process
                             // for an async signal or to send an async packet while running
                             // but we might have been single stepping and received the
@@ -453,7 +453,7 @@
                             // a lot of trouble for us!
                             if (signo != SIGINT && signo != SIGSTOP)
                             {
-                                continue_after_aync = false;
+                                continue_after_async = false;
 
                                 // We didn't get a a SIGINT or SIGSTOP, so try for a
                                 // very brief time (1 ms) to get another stop reply
@@ -470,7 +470,7 @@
                                         // our interrupt didn't stop the target so we
                                         // shouldn't continue after the async signal
                                         // or packet is sent...
-                                        continue_after_aync = false;
+                                        continue_after_async = false;
                                         break;
                                     }
                                 }
@@ -514,7 +514,7 @@
                                                        Host::GetSignalAsCString (async_signal));
 
                                 // Set the continue packet to resume even if the
                                 // interrupt didn't cause our stop (ignore continue_after_aync)
                                 continue_packet.assign(signal_packet, signal_packet_len);
                                 continue;
                             }
@@ -548,13 +548,13 @@
                             m_async_packet_predicate.SetValue(false, eBroadcastAlways);
 
                             if (packet_log) 
-                                packet_log->Printf ("async: sent packet, continue_after_aync = %i", continue_after_aync);
+                                packet_log->Printf ("async: sent packet, continue_after_async = %i", continue_after_async);
 
                             // Set the continue packet to resume if our interrupt
                             // for the async packet did cause the stop
-                            if (continue_after_aync)
+                            if (continue_after_async)
                             {
-                                continue_packet.assign (1, 'c');
+                                //continue_packet.assign (1, 'c');
                                 continue;
                             }
                         }
@@ -514,7 +514,7 @@
 
                                 // Set the continue packet to resume even if the
-                                // interrupt didn't cause our stop (ignore continue_after_aync)
+                                // interrupt didn't cause our stop (ignore continue_after_async)
                                 continue_packet.assign(signal_packet, signal_packet_len);
                                 continue;





More information about the lldb-commits mailing list